@@ -3,17 +3,17 @@ import repository from './repository'
 const resource = 'identities'
 
 export default {
-  getAll () {
+  getAll() {
     return repository.get(`${resource}/`)
   },
-  exportAll () {
+  exportAll() {
     return repository.get(`/${resource}/export/`)
   },
-  importFromCSV (data) {
+  importFromCSV(data) {
     return repository.post(`/${resource}/import/`, data, {
       headers: {
-        'Content-Type': 'multipart/form-data'
-      }
+        'Content-Type': 'multipart/form-data',
+      },
     })
-  }
+  },
 }
