@@ -68,12 +68,18 @@ class DomainSerializer(serializers.ModelSerializer):
             "message_limit",
             "creation",
             "last_modification",
+            "allocated_quota_in_percent",
+            "mailbox_count",
+            "mbalias_count",
+            "domainalias_count",
+            "enable_dns_checks",
         )
         read_only_fields = (
             "pk",
             "dkim_public_key",
             "dns_global_status",
-            "allocated_quota_in_percent" "mailbox_count",
+            "allocated_quota_in_percent",
+            "mailbox_count",
             "mbalias_count",
             "domainalias_count",
             "enable_dns_checks",
@@ -202,6 +208,7 @@ class MailboxSerializer(serializers.ModelSerializer):
             "message_limit",
             "quota_usage",
             "is_send_only",
+            "sent_messages_in_percent",
         )
 
     def get_quota_usage(self, mb) -> int:
