@@ -6,6 +6,7 @@ from unittest import mock
 
 import dns.resolver
 
+from django.core.cache import cache
 from django.test import override_settings
 from django.urls import reverse
 
@@ -25,10 +26,11 @@ class DomainAPITestCase(ModoAPITestCase):
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create test data."""
-        super(DomainAPITestCase, cls).setUpTestData()
+        super().setUpTestData()
         factories.populate_database()
         cls.da_token = Token.objects.create(
-            user=core_models.User.objects.get(username="admin@test.com"))
+            user=core_models.User.objects.get(username="admin@test.com")
+        )
 
     def test_get_domains(self):
         """Retrieve a list of domains."""
@@ -37,8 +39,7 @@ class DomainAPITestCase(ModoAPITestCase):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.data), 2)
         domain = response.data[0]
-        url = reverse(
-            "v1:domain-detail", args=[domain["pk"]])
+        url = reverse("v1:domain-detail", args=[domain["pk"]])
         response = self.client.get(url)
         data = response.json()
         self.assertEqual(response.status_code, 200)
@@ -65,35 +66,53 @@ class DomainAPITestCase(ModoAPITestCase):
         self.assertEqual(response.status_code, 400)
         self.assertIn("default_mailbox_quota", response.data)
 
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         response = self.client.post(
-            url, {"name": "test4.com", "default_mailbox_quota": 10})
+            url, {"name": "test4.com", "default_mailbox_quota": 10}
+        )
         self.assertEqual(response.status_code, 403)
 
+    def test_create_utf8(self):
+        """Test the creation of a domain with non-ASCII characters."""
+        url = reverse("v1:domain-list")
+        values = {
+            "name": "pouét.com",
+            "quota": 1000,
+            "default_mailbox_quota": 100,
+            "type": "domain",
+        }
+        response = self.client.post(url, values, format="json")
+        self.assertEqual(response.status_code, 201)
+        dom = models.Domain.objects.get(name="pouét.com")
+        self.assertEqual(dom.name, "pouét.com")
+        self.assertEqual(dom.quota, 1000)
+        self.assertEqual(dom.default_mailbox_quota, 100)
+        self.assertTrue(dom.enabled)
+        self.assertFalse(dom.admins)
+
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     @mock.patch("socket.getaddrinfo")
     def test_create_domain_with_mx_check(self, mock_getaddrinfo, mock_query):
         """Check domain creation when MX check is activated."""
+        mock_query.side_effect = utils.mock_dns_query_result
+        mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         self.set_global_parameter("enable_admin_limits", False, app="limits")
         self.set_global_parameter("valid_mxs", "192.0.2.1 2001:db8::1")
         self.set_global_parameter("domains_must_have_authorized_mx", True)
         reseller = core_factories.UserFactory(
-            username="reseller", groups=("Resellers", ))
+            username="reseller", groups=("Resellers",)
+        )
         token = Token.objects.create(user=reseller)
         self.client.credentials(HTTP_AUTHORIZATION="Token " + token.key)
 
         url = reverse("v1:domain-list")
-        mock_query.side_effect = utils.mock_dns_query_result
-        mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         response = self.client.post(
-            url, {"name": "no-mx.example.com", "quota": 0,
-                  "default_mailbox_quota": 10}
+            url, {"name": "no-mx.example.com", "quota": 0, "default_mailbox_quota": 10}
         )
         self.assertEqual(response.status_code, 400)
         self.assertEqual(
-            response.json()["name"][0],
-            "No authorized MX record found for this domain")
+            response.json()["name"][0], "No authorized MX record found for this domain"
+        )
 
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         response = self.client.post(
@@ -104,25 +123,28 @@ class DomainAPITestCase(ModoAPITestCase):
     def test_update_domain(self):
         """Check domain update."""
         domain = models.Domain.objects.get(name="test.com")
-        models.Mailbox.objects.filter(
-            domain__name="test.com", address="user").update(
-                use_domain_quota=True)
+        models.Mailbox.objects.filter(domain__name="test.com", address="user").update(
+            use_domain_quota=True
+        )
         url = reverse("v1:domain-detail", args=[domain.pk])
         response = self.client.put(
-            url, {"name": "test.com", "default_mailbox_quota": 1000})
+            url, {"name": "test.com", "default_mailbox_quota": 1000}
+        )
         self.assertEqual(response.status_code, 200)
         domain.refresh_from_db()
         self.assertEqual(domain.default_mailbox_quota, 1000)
-        mb = models.Mailbox.objects.get(
-            domain__name="test.com", address="user")
+        mb = models.Mailbox.objects.get(domain__name="test.com", address="user")
         self.assertEqual(mb.quota, 1000)
 
         response = self.client.put(
-            url, {"name": "test42.com", "default_mailbox_quota": 1000})
+            url, {"name": "test42.com", "default_mailbox_quota": 1000}
+        )
         self.assertEqual(response.status_code, 200)
         self.assertTrue(
             models.Mailbox.objects.filter(
-                address="user", domain__name="test42.com").exists())
+                address="user", domain__name="test42.com"
+            ).exists()
+        )
 
     def test_patch_domain(self):
         """Check domain partial update."""
@@ -133,6 +155,15 @@ class DomainAPITestCase(ModoAPITestCase):
         domain.refresh_from_db()
         self.assertEqual(domain.name, "toto.test")
 
+    def test_remove_dkim_domain(self):
+        """Try to remove DKIM from a domain."""
+        domain = models.Domain.objects.get(name="test.com")
+        url = reverse("v1:domain-detail", args=[domain.pk])
+        response = self.client.put(url, {"name": "test.com", "enable_dkim": False})
+        self.assertEqual(response.status_code, 200)
+        domain.refresh_from_db()
+        self.assertEqual(domain.dkim_private_key_path, "")
+
     def test_delete_domain(self):
         """Try to delete a domain."""
         domain = models.Domain.objects.get(name="test.com")
@@ -148,14 +179,17 @@ class DomainAliasAPITestCase(ModoAPITestCase):
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create test data."""
-        super(DomainAliasAPITestCase, cls).setUpTestData()
+        super().setUpTestData()
         factories.populate_database()
         cls.dom_alias1 = factories.DomainAliasFactory(
-            name="dalias1.com", target__name="test.com")
+            name="dalias1.com", target__name="test.com"
+        )
         cls.dom_alias2 = factories.DomainAliasFactory(
-            name="dalias2.com", target__name="test2.com")
+            name="dalias2.com", target__name="test2.com"
+        )
         cls.da_token = Token.objects.create(
-            user=core_models.User.objects.get(username="admin@test.com"))
+            user=core_models.User.objects.get(username="admin@test.com")
+        )
 
     def test_get(self):
         """Retrieve a list of domain aliases."""
@@ -163,19 +197,17 @@ class DomainAliasAPITestCase(ModoAPITestCase):
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.data), 2)
-        url = reverse(
-            "v1:domain_alias-detail", args=[response.data[0]["pk"]])
+        url = reverse("v1:domain_alias-detail", args=[response.data[0]["pk"]])
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.data["name"], "dalias1.com")
 
         url = reverse("v1:domain_alias-list")
-        response = self.client.get("{}?domain=test.com".format(url))
+        response = self.client.get(f"{url}?domain=test.com")
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.data), 1)
 
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         response = self.client.get(reverse("v1:domain_alias-list"))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.data), 0)
@@ -184,31 +216,25 @@ class DomainAliasAPITestCase(ModoAPITestCase):
         """Try to create a new domain alias."""
         url = reverse("v1:domain_alias-list")
         target = models.Domain.objects.get(name="test.com")
-        data = {
-            "name": "dalias3.com",
-            "target": target.pk
-        }
+        data = {"name": "dalias3.com", "target": target.pk}
         response = self.client.post(url, data, format="json")
         self.assertEqual(response.status_code, 201)
 
         dalias = response.json()
-        dalias = models.DomainAlias.objects.filter(
-            pk=dalias["pk"]).first()
+        dalias = models.DomainAlias.objects.filter(pk=dalias["pk"]).first()
         self.assertEqual(dalias.target, target)
 
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         response = self.client.post(
-            url, {"name": "dalias4.com", "target": target.pk}, format="json")
+            url, {"name": "dalias4.com", "target": target.pk}, format="json"
+        )
         self.assertEqual(response.status_code, 403)
 
     def test_put(self):
         """Try to update a domain alias."""
         dalias = models.DomainAlias.objects.get(name="dalias1.com")
         url = reverse("v1:domain_alias-detail", args=[dalias.pk])
-        data = {
-            "name": "dalias3.com", "target": dalias.target.pk
-        }
+        data = {"name": "dalias3.com", "target": dalias.target.pk}
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
 
@@ -222,8 +248,7 @@ class DomainAliasAPITestCase(ModoAPITestCase):
         url = reverse("v1:domain_alias-detail", args=[dalias.pk])
         response = self.client.delete(url)
         self.assertEqual(response.status_code, 204)
-        self.assertFalse(
-            models.DomainAlias.objects.filter(pk=dalias.pk).exists())
+        self.assertFalse(models.DomainAlias.objects.filter(pk=dalias.pk).exists())
 
 
 class AccountAPITestCase(ModoAPITestCase):
@@ -233,27 +258,28 @@ class AccountAPITestCase(ModoAPITestCase):
         "username": "fromapi@test.com",
         "role": "SimpleUsers",
         "password": "Toto1234",
-        "mailbox": {
-            "full_address": "fromapi@test.com",
-            "quota": 10
-        }
+        "mailbox": {"full_address": "fromapi@test.com", "quota": 10},
     }
 
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create test data."""
-        super(AccountAPITestCase, cls).setUpTestData()
+        super().setUpTestData()
         factories.populate_database()
         cls.da_token = Token.objects.create(
-            user=core_models.User.objects.get(username="admin@test.com"))
+            user=core_models.User.objects.get(username="admin@test.com")
+        )
 
     def setUp(self):
         """Test setup."""
         super().setUp()
-        self.set_global_parameters({
-            "enable_admin_limits": False,
-            "enable_domain_limits": False
-        }, app="limits")
+        self.set_global_parameters(
+            {"enable_admin_limits": False, "enable_domain_limits": False}, app="limits"
+        )
+
+    def tearDown(self):
+        # Make sure API calls do not get throttled
+        cache.clear()
 
     def test_get_accounts(self):
         """Retrieve a list of accounts."""
@@ -263,17 +289,17 @@ class AccountAPITestCase(ModoAPITestCase):
         response = response.json()
         self.assertEqual(len(response), 5)
 
-        response = self.client.get("{}?domain=test.com".format(url))
+        response = self.client.get(f"{url}?domain=test.com")
         self.assertEqual(response.status_code, 200)
         response = response.json()
         self.assertEqual(len(response), 2)
 
-        response = self.client.get("{}?domain=pouet.com".format(url))
+        response = self.client.get(f"{url}?domain=pouet.com")
         self.assertEqual(response.status_code, 200)
         response = response.json()
         self.assertEqual(len(response), 0)
 
-        response = self.client.get("{}?search=user@test.com".format(url))
+        response = self.client.get(f"{url}?search=user@test.com")
         self.assertEqual(response.status_code, 200)
         response = response.json()
         self.assertEqual(len(response), 1)
@@ -341,12 +367,10 @@ class AccountAPITestCase(ModoAPITestCase):
         response = self.client.post(url, data, format="json")
         self.assertEqual(response.status_code, 201)
         domain = models.Domain.objects.get(name="test.com")
-        admin = core_models.User.objects.get(
-            pk=response.json()["pk"])
+        admin = core_models.User.objects.get(pk=response.json()["pk"])
         self.assertIn(admin, domain.admins)
 
-        response = self.client.get(
-            reverse("v1:account-detail", args=[admin.pk]))
+        response = self.client.get(reverse("v1:account-detail", args=[admin.pk]))
         self.assertEqual(response.status_code, 200)
         self.assertIn("domains", response.json())
 
@@ -366,8 +390,7 @@ class AccountAPITestCase(ModoAPITestCase):
         user = core_models.User.objects.filter(pk=account["pk"]).first()
         self.assertIsNot(user, None)
         self.assertIsNot(user.mailbox, None)
-        self.assertEqual(
-            user.mailbox.quota, user.mailbox.domain.default_mailbox_quota)
+        self.assertEqual(user.mailbox.quota, user.mailbox.domain.default_mailbox_quota)
 
     def test_create_existing_account(self):
         """Check if unicity is respected."""
@@ -394,8 +417,7 @@ class AccountAPITestCase(ModoAPITestCase):
 
     def test_create_account_as_domadmin(self):
         """As DomainAdmin, try to create a new account."""
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         data = copy.deepcopy(self.ACCOUNT_DATA)
         data["mailbox"]["quota"] = 1000
         url = reverse("v1:account-list")
@@ -404,8 +426,7 @@ class AccountAPITestCase(ModoAPITestCase):
         self.assertEqual(response.status_code, 400)
 
         data["username"] = "fromapi@test2.com"
-        data["mailbox"].update({"full_address": "fromapi@test2.com",
-                                "quota": 10})
+        data["mailbox"].update({"full_address": "fromapi@test2.com", "quota": 10})
         response = self.client.post(url, data, format="json")
         # Should fail because admin has no access to @test2.com domain
         self.assertEqual(response.status_code, 400)
@@ -432,8 +453,8 @@ class AccountAPITestCase(ModoAPITestCase):
             "password": "Toto1234",
             "mailbox": {
                 "full_address": "fromapi@test.com",
-                "quota": account.mailbox.quota
-            }
+                "quota": account.mailbox.quota,
+            },
         }
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
@@ -450,14 +471,9 @@ class AccountAPITestCase(ModoAPITestCase):
 
     def test_update_account_with_no_mailbox(self):
         """Try to disable an account."""
-        account = core_factories.UserFactory(
-            username="reseller", groups=("Resellers", ))
+        account = core_factories.UserFactory(username="reseller", groups=("Resellers",))
         url = reverse("v1:account-detail", args=[account.pk])
-        data = {
-            "username": "reseller",
-            "role": account.role,
-            "is_active": False
-        }
+        data = {"username": "reseller", "role": account.role, "is_active": False}
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
 
@@ -470,7 +486,7 @@ class AccountAPITestCase(ModoAPITestCase):
             "username": "fromapi@test.com",
             "mailbox": {
                 "full_address": "fromapi@test.com",
-            }
+            },
         }
         response = self.client.patch(url, data, format="json")
         self.assertEqual(response.status_code, 200)
@@ -488,9 +504,9 @@ class AccountAPITestCase(ModoAPITestCase):
             "password": "Toto1234",
             "mailbox": {
                 "full_address": account.mailbox.full_address,
-                "quota": account.mailbox.quota
+                "quota": account.mailbox.quota,
             },
-            "domains": ["test.com", "test2.com"]
+            "domains": ["test.com", "test2.com"],
         }
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
@@ -515,8 +531,8 @@ class AccountAPITestCase(ModoAPITestCase):
             "password": "Toto1234",
             "mailbox": {
                 "full_address": "fromapi@test3.com",
-                "quota": account.mailbox.quota
-            }
+                "quota": account.mailbox.quota,
+            },
         }
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 404)
@@ -529,20 +545,17 @@ class AccountAPITestCase(ModoAPITestCase):
         url = reverse("v1:account-detail", args=[account.pk])
         response = self.client.delete(url)
         self.assertEqual(response.status_code, 204)
-        self.assertFalse(
-            core_models.User.objects.filter(pk=account.pk).exists())
+        self.assertFalse(core_models.User.objects.filter(pk=account.pk).exists())
         self.assertFalse(domadmin.can_access(account))
 
     def test_account_exists(self):
         """Validate /exists/ service."""
         url = reverse("v1:account-exists")
-        response = self.client.get(
-            "{}?email={}".format(url, "user@test.com"))
+        response = self.client.get("{}?email={}".format(url, "user@test.com"))
         self.assertEqual(response.status_code, 200)
         content = response.json()
         self.assertTrue(content["exists"])
-        response = self.client.get(
-            "{}?email={}".format(url, "pipo@test.com"))
+        response = self.client.get("{}?email={}".format(url, "pipo@test.com"))
         self.assertEqual(response.status_code, 200)
         content = response.json()
         self.assertFalse(content["exists"])
@@ -552,17 +565,16 @@ class AccountAPITestCase(ModoAPITestCase):
     def test_change_password(self):
         """Check the change password service."""
         account = core_models.User.objects.get(username="user@test.com")
-        url = reverse(
-            "v1:account-password", args=[account.pk])
+        url = reverse("v1:account-password", args=[account.pk])
         response = self.client.put(
-            url, {"password": "toto", "new_password": "pass"},
-            format="json")
+            url, {"password": "toto", "new_password": "pass"}, format="json"
+        )
         # must fail because password is too weak
         self.assertEqual(response.status_code, 400)
 
         response = self.client.put(
-            url, {"password": "toto", "new_password": "Toto1234"},
-            format="json")
+            url, {"password": "toto", "new_password": "Toto1234"}, format="json"
+        )
         self.assertEqual(response.status_code, 200)
         account.refresh_from_db()
         self.assertTrue(account.check_password("Toto1234"))
@@ -575,13 +587,16 @@ class AccountAPITestCase(ModoAPITestCase):
         response = self.client.post(url)
         self.assertEqual(response.status_code, 404)
 
-        self.set_global_parameters({
-            "sms_password_recovery": True,
-            "sms_provider": "ovh",
-            "sms_ovh_application_key": "key",
-            "sms_ovh_application_secret": "secret",
-            "sms_ovh_consumer_key": "consumer"
-        }, app="core")
+        self.set_global_parameters(
+            {
+                "sms_password_recovery": True,
+                "sms_provider": "ovh",
+                "sms_ovh_application_key": "key",
+                "sms_ovh_application_secret": "secret",
+                "sms_ovh_consumer_key": "consumer",
+            },
+            app="core",
+        )
         # No email provided
         response = self.client.post(url)
         self.assertEqual(response.status_code, 400)
@@ -605,21 +620,19 @@ class AliasAPITestCase(ModoAPITestCase):
 
     ALIAS_DATA = {
         "address": "alias_fromapi@test.com",
-        "recipients": [
-            "user@test.com", "postmaster@test.com", "user_éé@nonlocal.com"
-        ]
+        "recipients": ["user@test.com", "postmaster@test.com", "user_éé@nonlocal.com"],
     }
 
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create test data."""
-        super(AliasAPITestCase, cls).setUpTestData()
-        cls.localconfig.parameters.set_value(
-            "enable_admin_limits", False, app="limits")
+        super().setUpTestData()
+        cls.localconfig.parameters.set_value("enable_admin_limits", False, app="limits")
         cls.localconfig.save()
         factories.populate_database()
         cls.da_token = Token.objects.create(
-            user=core_models.User.objects.get(username="admin@test.com"))
+            user=core_models.User.objects.get(username="admin@test.com")
+        )
 
     def test_get_aliases(self):
         """Retrieve a list of aliases."""
@@ -629,7 +642,7 @@ class AliasAPITestCase(ModoAPITestCase):
         response = response.json()
         self.assertEqual(len(response), 3)
 
-        response = self.client.get("{}?domain=test.com".format(url))
+        response = self.client.get(f"{url}?domain=test.com")
         self.assertEqual(response.status_code, 200)
         response = response.json()
         self.assertEqual(len(response), 3)
@@ -654,13 +667,23 @@ class AliasAPITestCase(ModoAPITestCase):
         domadmin = core_models.User.objects.get(username="admin@test.com")
         self.assertTrue(domadmin.can_access(alias))
         self.assertEqual(alias.aliasrecipient_set.count(), 3)
-        self.assertTrue(alias.aliasrecipient_set.filter(
-            address="user@test.com", r_mailbox__isnull=False).exists())
-        self.assertTrue(alias.aliasrecipient_set.filter(
-            address="postmaster@test.com", r_alias__isnull=False).exists())
-        self.assertTrue(alias.aliasrecipient_set.filter(
-            address="user_éé@nonlocal.com",
-            r_mailbox__isnull=True, r_alias__isnull=True).exists())
+        self.assertTrue(
+            alias.aliasrecipient_set.filter(
+                address="user@test.com", r_mailbox__isnull=False
+            ).exists()
+        )
+        self.assertTrue(
+            alias.aliasrecipient_set.filter(
+                address="postmaster@test.com", r_alias__isnull=False
+            ).exists()
+        )
+        self.assertTrue(
+            alias.aliasrecipient_set.filter(
+                address="user_éé@nonlocal.com",
+                r_mailbox__isnull=True,
+                r_alias__isnull=True,
+            ).exists()
+        )
 
         # Create catchall alias
         data = copy.deepcopy(self.ALIAS_DATA)
@@ -668,10 +691,20 @@ class AliasAPITestCase(ModoAPITestCase):
         response = self.client.post(url, data, format="json")
         self.assertEqual(response.status_code, 201)
 
+    def test_create_duplicate_alias(self):
+        url = reverse("v1:alias-list")
+        response = self.client.post(url, self.ALIAS_DATA, format="json")
+        self.assertEqual(response.status_code, 201)
+
+        # Try with same address but different case
+        data = copy.deepcopy(self.ALIAS_DATA)
+        data["address"] = "ALIAS_fromapi@test.com"
+        response = self.client.post(url, data, format="json")
+        self.assertEqual(response.status_code, 400)
+
     def test_create_alias_as_domadmin(self):
         """As DomainAdmin, try to create a new alias."""
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         url = reverse("v1:alias-list")
         response = self.client.post(url, self.ALIAS_DATA, format="json")
         self.assertEqual(response.status_code, 201)
@@ -689,26 +722,20 @@ class AliasAPITestCase(ModoAPITestCase):
         url = reverse("v1:alias-detail", args=[alias.pk])
         data = {
             "address": "alias@test.com",
-            "recipients": ["user@test.com", "user@nonlocal.com"]
+            "recipients": ["user@test.com", "user@nonlocal.com"],
         }
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
 
         alias.refresh_from_db()
         self.assertEqual(alias.aliasrecipient_set.count(), 2)
-        data = {
-            "address": "alias@test.com",
-            "recipients": ["user@nonlocal.com"]
-        }
+        data = {"address": "alias@test.com", "recipients": ["user@nonlocal.com"]}
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 200)
         alias.refresh_from_db()
         self.assertEqual(alias.aliasrecipient_set.count(), 1)
 
-        data = {
-            "address": "alias@test.com",
-            "recipients": []
-        }
+        data = {"address": "alias@test.com", "recipients": []}
         response = self.client.put(url, data, format="json")
         self.assertEqual(response.status_code, 400)
 
@@ -720,13 +747,12 @@ class AliasAPITestCase(ModoAPITestCase):
         url = reverse("v1:alias-detail", args=[alias.pk])
         response = self.client.delete(url)
         self.assertEqual(response.status_code, 204)
-        self.assertFalse(
-            models.Alias.objects.filter(pk=alias.pk).exists())
+        self.assertFalse(models.Alias.objects.filter(pk=alias.pk).exists())
         self.assertFalse(domadmin.can_access(alias))
         self.assertFalse(
             models.AliasRecipient.objects.filter(
-                address="user@test.com", alias__address="alias@test.com")
-            .exists()
+                address="user@test.com", alias__address="alias@test.com"
+            ).exists()
         )
 
 
@@ -736,19 +762,19 @@ class SenderAddressAPITestCase(ModoAPITestCase):
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create test data."""
-        super(SenderAddressAPITestCase, cls).setUpTestData()
-        cls.localconfig.parameters.set_value(
-            "enable_admin_limits", False, app="limits")
+        super().setUpTestData()
+        cls.localconfig.parameters.set_value("enable_admin_limits", False, app="limits")
         cls.localconfig.save()
         factories.populate_database()
         cls.sa1 = factories.SenderAddressFactory(
             address="test@domain.ext",
             mailbox__user__username="user@test.com",
             mailbox__address="user",
-            mailbox__domain__name="test.com"
+            mailbox__domain__name="test.com",
         )
         cls.da_token = Token.objects.create(
-            user=core_models.User.objects.get(username="admin@test.com"))
+            user=core_models.User.objects.get(username="admin@test.com")
+        )
 
     def test_list(self):
         """Retrieve a list of sender addresses."""
@@ -761,35 +787,31 @@ class SenderAddressAPITestCase(ModoAPITestCase):
     def test_create(self):
         """Create a new sender addresses."""
         url = reverse("v1:sender_address-list")
-        mbox = models.Mailbox.objects.get(
-            address="admin", domain__name="test.com")
+        mbox = models.Mailbox.objects.get(address="admin", domain__name="test.com")
         data = {"address": "@extdomain.test", "mailbox": mbox.pk}
         response = self.client.post(url, data)
         self.assertEqual(response.status_code, 201)
 
-        self.client.credentials(
-            HTTP_AUTHORIZATION="Token " + self.da_token.key)
+        self.client.credentials(HTTP_AUTHORIZATION="Token " + self.da_token.key)
         data = {"address": "user@test2.com", "mailbox": mbox.pk}
         response = self.client.post(url, data)
         self.assertEqual(response.status_code, 400)
         self.assertEqual(
-            response.json()["address"][0],
-            "You don't have access to this domain.")
+            response.json()["address"][0], "You don't have access to this domain."
+        )
 
-        mbox = models.Mailbox.objects.get(
-            address="admin", domain__name="test2.com")
+        mbox = models.Mailbox.objects.get(address="admin", domain__name="test2.com")
         data = {"address": "toto@titi.com", "mailbox": mbox.pk}
         response = self.client.post(url, data)
         self.assertEqual(response.status_code, 400)
         self.assertEqual(
-            response.json()["mailbox"][0],
-            "You don't have access to this mailbox.")
+            response.json()["mailbox"][0], "You don't have access to this mailbox."
+        )
 
     def test_patch(self):
         """Patch an existing sender address."""
         url = reverse("v1:sender_address-detail", args=[self.sa1.pk])
-        mbox = models.Mailbox.objects.get(
-            address="user", domain__name="test.com")
+        mbox = models.Mailbox.objects.get(address="user", domain__name="test.com")
         data = {"address": "@extdomain.test"}
         response = self.client.patch(url, data)
         self.assertEqual(response.status_code, 200)
@@ -800,8 +822,7 @@ class SenderAddressAPITestCase(ModoAPITestCase):
     def test_update(self):
         """Update an existing sender address."""
         url = reverse("v1:sender_address-detail", args=[self.sa1.pk])
-        mbox = models.Mailbox.objects.get(
-            address="user", domain__name="test.com")
+        mbox = models.Mailbox.objects.get(address="user", domain__name="test.com")
         data = {"address": "@extdomain.test", "mailbox": mbox.pk}
         response = self.client.put(url, data)
         self.assertEqual(response.status_code, 200)
