@@ -61,6 +61,8 @@ class DomainSerializer(v1_serializers.DomainSerializer):
             "domain_admin",
             "transport",
             "opened_alarms_count",
+            "sent_messages",
+            "sent_messages_in_percent",
         )
 
     def __init__(self, *args, **kwargs):
@@ -221,9 +223,9 @@ class AdminGlobalParametersSerializer(serializers.Serializer):
     enable_dkim_checks = serializers.BooleanField(default=True)
     enable_dmarc_checks = serializers.BooleanField(default=True)
     enable_autoconfig_checks = serializers.BooleanField(default=True)
-    custom_dns_server = serializers.IPAddressField(allow_blank=True)
+    custom_dns_server = serializers.IPAddressField(allow_blank=True, allow_null=True)
     enable_dnsbl_checks = serializers.BooleanField(default=True)
-    dkim_keys_storage_dir = serializers.CharField(allow_blank=True)
+    dkim_keys_storage_dir = serializers.CharField(allow_blank=True, allow_null=True)
     dkim_default_key_length = serializers.ChoiceField(
         default=2048, choices=constants.DKIM_KEY_LENGTHS
     )
@@ -396,6 +398,20 @@ class AccountMeSerializer(v1_serializers.AccountSerializer):
         return [f"{p.content_type.app_label}.{p.codename}" for p in permissions]
 
 
+class AccountMeUpdateSerializer(serializers.ModelSerializer):
+    """Update serializer for connected user."""
+
+    class Meta:
+        model = core_models.User
+        fields = (
+            "first_name",
+            "last_name",
+            "language",
+            "phone_number",
+            "secondary_email",
+        )
+
+
 class AccountSerializer(v1_serializers.AccountSerializer):
     """Add support for user resources."""
 
@@ -729,7 +745,7 @@ class CSVImportSerializer(serializers.Serializer):
 class CSVIdentityImportSerializer(CSVImportSerializer):
     """Custom serializer for identity import."""
 
-    crypt_password = serializers.BooleanField()
+    crypt_passwords = serializers.BooleanField()
 
 
 class AlarmSerializer(serializers.ModelSerializer):
@@ -741,6 +757,11 @@ class AlarmSerializer(serializers.ModelSerializer):
         model = models.Alarm
 
 
+class AlarmBulkDeleteSerializer(serializers.Serializer):
+
+    ids = serializers.ListField(child=serializers.IntegerField())
+
+
 class AlarmSwitchStatusSerializer(serializers.Serializer):
     """Serializer to switch the status of an Alarm."""
 
