@@ -331,6 +331,16 @@ class AccountViewSetTestCase(ModoAPITestCase):
         resp = self.client.patch(url, data, format="json")
         self.assertEqual(resp.status_code, 200)
 
+    def test_update_quota(self):
+        account = core_models.User.objects.get(username="user@test.com")
+        url = reverse("v2:account-detail", args=[account.pk])
+        data = {
+            "mailbox": {"quota": 1},
+        }
+        resp = self.client.patch(url, data, format="json")
+        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(account.mailbox.quota, data["mailbox"]["quota"])
+
     def test_user_updates_password(self):
         account = core_models.User.objects.get(username="user@test.com")
         self.authenticate_user(account)
@@ -583,7 +593,7 @@ dlist; dlist@test.com; True; user1@test.com; user@extdomain.com
         )  # NOQA:E501
         self.client.post(
             reverse("v2:identities-import-from-csv"),
-            {"sourcefile": f, "crypt_password": True},
+            {"sourcefile": f, "crypt_passwords": True},
         )
         admin = core_models.User.objects.get(username="admin")
         u1 = core_models.User.objects.get(username="user1@test.com")
@@ -806,9 +816,10 @@ class AlarmViewSetTestCase(ModoAPITestCase):
 
     def test_bulk_delete(self):
         url = reverse("v2:alarm-bulk-delete")
-        resp = self.client.delete(url)
+        resp = self.client.post(url)
         self.assertEqual(resp.status_code, 400)
-        resp = self.client.delete(f"{url}?ids[]=toto")
+        data = {"ids": ["toto"]}
+        resp = self.client.post(url, data, format="json")
         self.assertEqual(resp.status_code, 400)
         alarm1 = factories.AlarmFactory(
             domain__name="test.com", mailbox=None, title="Test alarm"
@@ -816,7 +827,8 @@ class AlarmViewSetTestCase(ModoAPITestCase):
         alarm2 = factories.AlarmFactory(
             domain__name="test.com", mailbox=None, title="Test alarm"
         )
-        resp = self.client.delete(f"{url}?ids[]={alarm1.pk}&ids[]={alarm2.pk}")
+        data = {"ids": [alarm1.pk, alarm2.pk]}
+        resp = self.client.post(url, data, format="json")
         self.assertEqual(resp.status_code, 204)
         with self.assertRaises(models.Alarm.DoesNotExist):
             alarm1.refresh_from_db()
