@@ -7,10 +7,9 @@ from testfixtures import LogCapture
 
 from django.core import mail, management
 from django.test import override_settings
-from django.urls import reverse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
-from modoboa.core import factories as core_factories
+from modoboa.core import models as core_models, factories as core_factories
 from modoboa.lib.tests import ModoTestCase
 from . import utils
 from .. import factories, models
@@ -23,26 +22,25 @@ class MXTestCase(ModoTestCase):
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create some data."""
-        super(MXTestCase, cls).setUpTestData()
+        super().setUpTestData()
         cls.domain = factories.DomainFactory(name="modoboa.org")
         # should not exist
-        cls.bad_domain = factories.DomainFactory(
-            name="does-not-exist.example.com")
+        cls.bad_domain = factories.DomainFactory(name="does-not-exist.example.com")
         # Add domain admin with mailbox
         mb = factories.MailboxFactory(
-            address="admin", domain=cls.bad_domain,
+            address="admin",
+            domain=cls.bad_domain,
             user__username="admin@does-not-exist.example.com",
-            user__groups=("DomainAdmins", )
+            user__groups=("DomainAdmins",),
         )
         cls.bad_domain.add_admin(mb.user)
         # Add domain admin with no mailbox
         admin = core_factories.UserFactory(
-            username="admin2@does-not-exist.example.com",
-            groups=("DomainAdmins", ))
+            username="admin2@does-not-exist.example.com", groups=("DomainAdmins",)
+        )
         cls.bad_domain.add_admin(admin)
 
-        cls.localconfig.parameters.set_value(
-            "valid_mxs", "192.0.2.1 2001:db8::1")
+        cls.localconfig.parameters.set_value("valid_mxs", "192.0.2.1 2001:db8::1")
         cls.localconfig.save()
         models.MXRecord.objects.all().delete()
 
@@ -50,15 +48,15 @@ class MXTestCase(ModoTestCase):
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_management_command(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Check that command works fine."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         mock_g_gethostbyname.return_value = "1.2.3.4"
         self.assertEqual(models.MXRecord.objects.count(), 0)
         management.call_command("modo", "check_mx", "--no-dnsbl", "--ttl=0")
-        self.assertTrue(
-            models.MXRecord.objects.filter(domain=self.domain).exists())
+        self.assertTrue(models.MXRecord.objects.filter(domain=self.domain).exists())
 
         # we passed a ttl to 0. this will reset the cache this time
         qs = models.MXRecord.objects.filter(domain=self.domain)
@@ -78,32 +76,30 @@ class MXTestCase(ModoTestCase):
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_single_domain_update(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Update only one domain."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         mock_g_gethostbyname.return_value = "1.2.3.4"
-        management.call_command(
-            "modo", "check_mx", "--domain", self.domain.name)
-        self.assertTrue(
-            models.MXRecord.objects.filter(domain=self.domain).exists())
+        management.call_command("modo", "check_mx", "--domain", self.domain.name)
+        self.assertTrue(models.MXRecord.objects.filter(domain=self.domain).exists())
         self.assertFalse(
-            models.MXRecord.objects.filter(domain=self.bad_domain).exists())
+            models.MXRecord.objects.filter(domain=self.bad_domain).exists()
+        )
 
-        management.call_command(
-            "modo", "check_mx", "--domain", str(self.bad_domain.pk))
+        management.call_command("modo", "check_mx", "--domain", str(self.bad_domain.pk))
         self.assertFalse(
-            models.MXRecord.objects.filter(domain=self.bad_domain).exists())
+            models.MXRecord.objects.filter(domain=self.bad_domain).exists()
+        )
         self.assertEqual(len(mail.outbox), 1)
 
-        management.call_command(
-            "modo", "check_mx", "--domain", "toto.com")
+        management.call_command("modo", "check_mx", "--domain", "toto.com")
 
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
-    def test_invalid_mx(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+    def test_invalid_mx(self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
         """Test to check if invalid MX records are detected."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
@@ -111,16 +107,19 @@ class MXTestCase(ModoTestCase):
         domain = factories.DomainFactory(name="invalid-mx.com")
         # Add domain admin with mailbox
         mb = factories.MailboxFactory(
-            address="admin", domain=domain,
-            user__username="admin@{}".format(domain.name),
-            user__groups=("DomainAdmins", )
+            address="admin",
+            domain=domain,
+            user__username=f"admin@{domain.name}",
+            user__groups=("DomainAdmins",),
         )
         domain.add_admin(mb.user)
         management.call_command(
-            "modo", "check_mx", "--domain", domain.name, "--no-dnsbl")
+            "modo", "check_mx", "--domain", domain.name, "--no-dnsbl"
+        )
         self.assertEqual(domain.alarms.count(), 1)
         management.call_command(
-            "modo", "check_mx", "--domain", domain.name, "--no-dnsbl")
+            "modo", "check_mx", "--domain", domain.name, "--no-dnsbl"
+        )
         self.assertEqual(domain.alarms.count(), 1)
         self.assertEqual(len(mail.outbox), 1)
 
@@ -148,29 +147,64 @@ class MXTestCase(ModoTestCase):
             get_domain_mx_list("no-answer.example.Com")
             get_domain_mx_list("bad-response.example.com")
         log.check(
-            ("modoboa.admin", "ERROR",
-                _("No DNS record found for %s")
-                % "does-not-exist.example.com"),
-            ("modoboa.admin", "ERROR",
-                _("No MX record for %s") % "no-mx.example.com"),
+            (
+                "modoboa.admin",
+                "ERROR",
+                _("No DNS record found for %s") % "does-not-exist.example.com",
+            ),
+            ("modoboa.admin", "ERROR", _("No MX record for %s") % "no-mx.example.com"),
             ("modoboa.admin", "ERROR", _("No working name servers found")),
-            ("modoboa.admin", "WARNING",
+            (
+                "modoboa.admin",
+                "WARNING",
                 _("DNS resolution timeout, unable to query %s at the moment")
-             % "timeout.example.com"),
-            ("modoboa.admin", "ERROR",
-             _("No DNS record found for %s")
-             % "does-not-exist.example.com"),
-            ("modoboa.admin", "ERROR",
-             _("No DNS record found for %s")
-             % "does-not-exist.example.com"),
-            ("modoboa.admin", "WARNING",
-             _("Invalid IP address format for %(domain)s; %(addr)s")
-             % {"domain": "bad-response.example.com", "addr": "000.0.0.0"}),
-            ("modoboa.admin", "WARNING",
-             _("Invalid IP address format for %(domain)s; %(addr)s")
-             % {"domain": "bad-response.example.com", "addr": "000.0.0.0"}),
+                % "timeout.example.com",
+            ),
+            (
+                "modoboa.admin",
+                "ERROR",
+                _("No DNS record found for %s") % "does-not-exist.example.com",
+            ),
+            (
+                "modoboa.admin",
+                "ERROR",
+                _("No DNS record found for %s") % "does-not-exist.example.com",
+            ),
+            (
+                "modoboa.admin",
+                "WARNING",
+                _("Invalid IP address format for %(domain)s; %(addr)s")
+                % {"domain": "bad-response.example.com", "addr": "000.0.0.0"},
+            ),
+            (
+                "modoboa.admin",
+                "WARNING",
+                _("Invalid IP address format for %(domain)s; %(addr)s")
+                % {"domain": "bad-response.example.com", "addr": "000.0.0.0"},
+            ),
         )
 
+    @mock.patch("ipaddress.ip_address")
+    @mock.patch.object(dns.resolver.Resolver, "resolve")
+    def test_ipv6_logging(self, mock_query, mock_ip_address):
+        """Test to check that AAAA missing record is logged consistently."""
+        mock_query.side_effect = utils.mock_dns_query_result
+        mock_ip_address.side_effect = utils.mock_ip_address_result
+        localconfig = core_models.LocalConfig.objects.first()
+        localconfig.parameters.set_value("enable_ipv6_mx_checks", True, "admin")
+        localconfig.save()
+        with LogCapture("modoboa.admin") as log:
+            get_domain_mx_list("test3.com")
+        log.check(
+            ("modoboa.admin", "ERROR", _("No AAAA record for %s") % "mx3.example.com")
+        )
+        localconfig = core_models.LocalConfig.objects.first()
+        localconfig.parameters.set_value("enable_ipv6_mx_checks", False, "admin")
+        localconfig.save()
+        with LogCapture("modoboa.admin") as log2:
+            get_domain_mx_list("test3.com")
+        log2.check()
+
 
 @override_settings(DNSBL_PROVIDERS=["zen.spamhaus.org"])
 class DNSBLTestCase(ModoTestCase):
@@ -183,74 +217,69 @@ class DNSBLTestCase(ModoTestCase):
         cls.domain = factories.DomainFactory(name="modoboa.org")
         factories.DomainFactory(name="does-not-exist.example.com")
         cls.domain2 = factories.DomainFactory(
-            name="test.localhost")  # Should not be checked
+            name="test.localhost"
+        )  # Should not be checked
         cls.domain3 = factories.DomainFactory(
-            name="modoboa.com", enable_dns_checks=False)
+            name="modoboa.com", enable_dns_checks=False
+        )
         models.DNSBLResult.objects.all().delete()
 
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_management_command(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Check that command works fine."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         mock_g_gethostbyname.return_value = "1.2.3.4"
         self.assertEqual(models.DNSBLResult.objects.count(), 0)
         management.call_command("modo", "check_mx")
-        self.assertTrue(
-            models.DNSBLResult.objects.filter(domain=self.domain).exists())
+        self.assertTrue(models.DNSBLResult.objects.filter(domain=self.domain).exists())
         self.assertFalse(
-            models.DNSBLResult.objects.filter(domain=self.domain3).exists())
-        response = self.client.get(
-            reverse("admin:dnsbl_domain_detail", args=[self.domain.pk]))
-        self.assertEqual(response.status_code, 200)
+            models.DNSBLResult.objects.filter(domain=self.domain3).exists()
+        )
         self.assertFalse(self.domain.uses_a_reserved_tld)
         self.assertTrue(self.domain2.uses_a_reserved_tld)
 
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
-    def test_notifications(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+    def test_notifications(self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
         """Check notifications."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         mock_g_gethostbyname.return_value = "127.0.0.4"
-        management.call_command(
-            "modo", "check_mx", "--email", "user@example.test")
+        management.call_command("modo", "check_mx", "--email", "user@example.test")
         self.assertEqual(len(mail.outbox), 2)
-    
+
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_notifications_wrong_dnsbl_response(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Check notifications."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
-        mock_g_gethostbyname.return_value = "127.255.255.254" #<--Spamhaus response when querying from an open resolver
-        management.call_command(
-            "modo", "check_mx", "--email", "user@example.test")
+        mock_g_gethostbyname.return_value = "127.255.255.254"  # <--Spamhaus response when querying from an open resolver
+        management.call_command("modo", "check_mx", "--email", "user@example.test")
         self.assertEqual(len(mail.outbox), 1)
 
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_management_command_no_dnsbl(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Check that command works fine without dnsbl."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
         mock_g_gethostbyname.return_value = "1.2.3.4"
         self.assertEqual(models.DNSBLResult.objects.count(), 0)
         management.call_command("modo", "check_mx", "--no-dnsbl")
-        self.assertFalse(
-            models.DNSBLResult.objects.filter(domain=self.domain).exists())
-        response = self.client.get(
-            reverse("admin:dnsbl_domain_detail", args=[self.domain.pk]))
-        self.assertEqual(response.status_code, 200)
+        self.assertFalse(models.DNSBLResult.objects.filter(domain=self.domain).exists())
 
 
 class DNSChecksTestCase(ModoTestCase):
@@ -259,14 +288,15 @@ class DNSChecksTestCase(ModoTestCase):
     @classmethod
     def setUpTestData(cls):  # NOQA:N802
         """Create some data."""
-        super(DNSChecksTestCase, cls).setUpTestData()
+        super().setUpTestData()
         cls.domain = factories.DomainFactory(name="dns-checks.com")
 
     @mock.patch("gevent.socket.gethostbyname")
     @mock.patch("socket.getaddrinfo")
     @mock.patch.object(dns.resolver.Resolver, "resolve")
     def test_management_command(
-            self, mock_query, mock_getaddrinfo, mock_g_gethostbyname):
+        self, mock_query, mock_getaddrinfo, mock_g_gethostbyname
+    ):
         """Check that command works fine."""
         mock_query.side_effect = utils.mock_dns_query_result
         mock_getaddrinfo.side_effect = utils.mock_ip_query_result
