@@ -19,7 +19,6 @@ from modoboa.admin import (
 from modoboa.core import models, constants
 from modoboa.core.tests import utils
 from modoboa.lib.tests import ModoAPITestCase
-from rest_framework.authtoken.models import Token
 
 DOVEADM_TEST_PATH = utils.get_doveadm_test_path()
 DOVECOT_USER = getpass.getuser()
@@ -183,6 +182,13 @@ class ParametersAPITestCase(ModoAPITestCase):
 
 
 class AccountViewSetTestCase(ModoAPITestCase):
+
+    @classmethod
+    def setUpTestData(cls):  # NOQA:N802
+        """Create test data."""
+        super().setUpTestData()
+        factories.populate_database()
+
     def test_me(self):
         url = reverse("v2:account-me")
         resp = self.client.get(url)
@@ -190,6 +196,18 @@ class AccountViewSetTestCase(ModoAPITestCase):
         me = resp.json()
         self.assertEqual(me["username"], "admin")
 
+    def test_update_me(self):
+        url = reverse("v2:account-me")
+        data = {
+            "first_name": "First name",
+            "secondary_email": "toto@iti.com",
+            "language": "fr",
+        }
+        resp = self.client.put(url, data, format="json")
+        self.assertEqual(resp.status_code, 200)
+        me = resp.json()
+        self.assertEqual(me["secondary_email"], data["secondary_email"])
+
     def test_me_password(self, password_ko="Toto1234", password_ok="password"):
         url = reverse("v2:account-check-me-password")
         resp = self.client.post(url, {"password": password_ko}, format="json")
@@ -261,6 +279,57 @@ class AccountViewSetTestCase(ModoAPITestCase):
         user.refresh_from_db()
         self.assertEqual(user.totp_enabled, False)
 
+    def test_available_applications(self):
+        url = reverse("v2:account-available-applications")
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
+        # admin -> only 2 apps.
+        self.assertEqual(len(resp.json()), 2)
+
+        # Domain admin with mailbox
+        dadmin = models.User.objects.get(username="admin@test.com")
+        self.authenticate_user(dadmin)
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(len(resp.json()), 5)
+
+        # Simple user
+        user = models.User.objects.get(username="user@test.com")
+        self.authenticate_user(user)
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(len(resp.json()), 4)
+
+    @override_settings(
+        MODOBOA_APPS=[
+            "modoboa",
+            "modoboa.core",
+            "modoboa.lib",
+            "modoboa.admin",
+            "modoboa.transport",
+            "modoboa.relaydomains",
+            "modoboa.limits",
+            "modoboa.parameters",
+            "modoboa.dnstools",
+            "modoboa.policyd",
+            "modoboa.maillog",
+            "modoboa.pdfcredentials",
+            "modoboa.dmarc",
+            "modoboa.imap_migration",
+            "modoboa.autoreply",
+            "modoboa.sievefilters",
+            "modoboa.rspamd",
+        ]
+    )
+    def test_available_applications_with_disabled(self):
+        url = reverse("v2:account-available-applications")
+        # Domain admin with mailbox
+        dadmin = models.User.objects.get(username="admin@test.com")
+        self.authenticate_user(dadmin)
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(len(resp.json()), 1)
+
 
 class PasswordResetTestCase(AccountViewSetTestCase):
     def __init__(self, *args, **kwargs):
@@ -268,15 +337,6 @@ class PasswordResetTestCase(AccountViewSetTestCase):
         self.id = 0
         self.sms_token = 0
 
-    @classmethod
-    def setUpTestData(cls):  # NOQA:N802
-        """Create test data."""
-        super().setUpTestData()
-        factories.populate_database()
-        cls.da_token = Token.objects.create(
-            user=models.User.objects.get(username="admin@test.com")
-        )
-
     @mock.patch("ovh.Client.get")
     @mock.patch("ovh.Client.post")
     def test_reset_password(self, client_post, client_get):
@@ -610,3 +670,21 @@ class NewsFeedAPIViewTestCase(ModoAPITestCase):
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertIn("modoboa", response.json()[0]["link"])
+
+
+class StatisticsAPIViewTestCase(ModoAPITestCase):
+
+    @classmethod
+    def setUpTestData(cls):
+        """Create test data."""
+        super().setUpTestData()
+        factories.populate_database()
+
+    def test_get_statistics(self):
+        url = reverse("v2:statistics")
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        stats = response.json()
+        self.assertEqual(stats["domain_count"], 2)
+        self.assertEqual(stats["account_count"], 5)
+        self.assertEqual(stats["alias_count"], 3)
