@@ -32,16 +32,21 @@ urlpatterns += [
         views.ComponentsInformationAPIView.as_view(),
         name="components_information",
     ),
-    path(
-        "admin/notifications/",
-        views.NotificationsAPIView.as_view(),
-        name="notifications",
-    ),
     path(
         "admin/news_feed/",
         views.NewsFeedAPIView.as_view(),
         name="news-feed",
     ),
+    path(
+        "admin/statistics/",
+        views.StatisticsAPIView.as_view(),
+        name="statistics",
+    ),
     path("capabilities/", views.CapabilitiesAPIView.as_view(), name="capabilities"),
+    path(
+        "notifications/",
+        views.NotificationsAPIView.as_view(),
+        name="notifications",
+    ),
     path("theme/", views.ThemeAPIView.as_view(), name="theme"),
 ]
