@@ -14,7 +14,8 @@ from drf_spectacular.utils import extend_schema
 from rest_framework import permissions, response
 from rest_framework.views import APIView
 
-from modoboa.core import signals
+from modoboa.admin import models as admin_models
+from modoboa.core import models, signals
 from modoboa.core.utils import check_for_updates, get_capabilities
 from modoboa.lib.permissions import IsSuperUser, IsPrivilegedUser
 from modoboa.lib.throttle import (
@@ -141,7 +142,9 @@ class PasswordResetConfirmView(APIView):
 class ComponentsInformationAPIView(APIView):
     """Retrieve information about installed components."""
 
-    permission_classes = [permissions.IsAuthenticated, IsSuperUser]
+    permission_classes = [
+        permissions.IsAuthenticated,
+    ]
     throttle_classes = [UserLesserDdosUser]
 
     @extend_schema(responses=serializers.ModoboaComponentSerializer(many=True))
@@ -226,3 +229,21 @@ class NewsFeedAPIView(APIView):
 
         serializer = serializers.NewsFeedEntrySerializer(entries, many=True)
         return response.Response(serializer.data)
+
+
+class StatisticsAPIView(APIView):
+    """Return some statistics about this modoboa instance."""
+
+    permission_classes = [permissions.IsAuthenticated, IsSuperUser]
+    throttle_classes = [UserLesserDdosUser]
+
+    @extend_schema(responses=serializers.StatisticsSerializer())
+    def get(self, request, *args, **kwargs):
+        data = {
+            "domain_count": admin_models.Domain.objects.count(),
+            "domain_alias_count": admin_models.DomainAlias.objects.count(),
+            "account_count": models.User.objects.count(),
+            "alias_count": admin_models.Alias.objects.filter(internal=False).count(),
+        }
+        serializer = serializers.StatisticsSerializer(data)
+        return response.Response(serializer.data)
