@@ -649,7 +649,7 @@ GLOBAL_PARAMETERS_STRUCT = collections.OrderedDict(
                             "new_versions_email_rcpt",
                             {
                                 "label": gettext_lazy("Recipient"),
-                                "display": "check_new_versions=true",
+                                "display": "send_new_versions_email=true",
                                 "help_text": gettext_lazy(
                                     "Recipient of new versions notification emails."
                                 ),
@@ -720,6 +720,17 @@ GLOBAL_PARAMETERS_STRUCT = collections.OrderedDict(
                                 ),
                             },
                         ),
+                        (
+                            "message_history_maximum_age",
+                            {
+                                "label": gettext_lazy(
+                                    "Retention time in message history"
+                                ),
+                                "help_text": gettext_lazy(
+                                    "Retention time (in days) of a message in the message history section"
+                                ),
+                            },
+                        ),
                         (
                             "items_per_page",
                             {
