@@ -5,6 +5,7 @@ from django.core.management.base import BaseCommand
 from django.utils import timezone
 
 from modoboa.core.models import Log
+from modoboa.maillog.models import Maillog
 from modoboa.parameters import tools as param_tools
 
 
@@ -41,4 +42,12 @@ class Command(BaseCommand):
         self.__vprint(f"Deleting logs older than {log_maximum_age} days...")
         limit = timezone.now() - datetime.timedelta(log_maximum_age)
         Log.objects.filter(date_created__lt=limit).delete()
+        message_history_maximum_age = param_tools.get_global_parameter(
+            "message_history_maximum_age"
+        )
+        self.__vprint(
+            f"Deleting messages in history older than {message_history_maximum_age} days..."
+        )
+        limit = timezone.now() - datetime.timedelta(message_history_maximum_age)
+        Maillog.objects.filter(date__lt=limit).delete()
         self.__vprint("Done.")
