@@ -57,6 +57,12 @@ class Command(BaseCommand):
             default=False,
             help="Omit everything related to frontend initialisation",
         )
+        parser.add_argument(
+            "--relative-urls-in-config",
+            action="store_true",
+            default=False,
+            help="Use relative urls in generated config.json file",
+        )
 
     def handle(self, *args, **options):
         """Command entry point."""
@@ -117,7 +123,10 @@ class Command(BaseCommand):
         base_uris = " ".join(base_uris_list)
         base_uri = base_uris_list[0]
         redirect_uris = " ".join([f"{uri}/login/logged" for uri in base_uris_list])
-        redirect_uri = redirect_uris.split(" ")[0]
+        if not options["relative_urls_in_config"]:
+            redirect_uri = redirect_uris.split(" ")[0]
+        else:
+            redirect_uri = "/login/logged"
         client_id = ""
         if options["dev"]:
             base_uri = "https://localhost:3000/"
@@ -160,14 +169,36 @@ class Command(BaseCommand):
                         f"{frontend_target_dir}/{entry.name}",
                         target_is_directory=entry.is_dir(),
                     )
+            api_base_url = "/api/v2"
+            api_doc_url = "/api/schema-v2/swagger/"
+            oauth_authority_url = "/api/o"
+            if not options["relative_urls_in_config"]:
+                api_base_url = f"{base_uri}{api_base_url}"
+                api_doc_url = f"{base_uri}{base_uri}"
+                oauth_authority_url = f"{base_uri}{oauth_authority_url}"
+                oauth_post_logout_redirect_uri = base_uri
+            else:
+                oauth_post_logout_redirect_uri = ""
+
             with open(f"{frontend_target_dir}/config.json", "w") as fp:
                 fp.write(
                     f"""{{
-  "API_BASE_URL": "{base_uri}/api/v2",
-  "OAUTH_AUTHORITY_URL": "{base_uri}/api/o",
+  "API_BASE_URL": "{api_base_url}",
+  "API_DOC_URL": "{api_doc_url}",
+  "OAUTH_AUTHORITY_URL": "{oauth_authority_url}",
   "OAUTH_CLIENT_ID": "{client_id}",
   "OAUTH_REDIRECT_URI": "{redirect_uri}",
-  "OAUTH_POST_REDIRECT_URI": "{base_uri}"
+  "OAUTH_POST_REDIRECT_URI": "{oauth_post_logout_redirect_uri}"
 }}
 """
                 )
+
+
+# ADD SIGNAL FOR THAT
+# def load_initial_data(self):
+#     """Create records for existing domains and co."""
+#     for dom in Domain.objects.all():
+#         policy = create_user_and_policy("@{0}".format(dom.name))
+#         for domalias in dom.domainalias_set.all():
+#             domalias_pattern = "@{0}".format(domalias.name)
+#             create_user_and_use_policy(domalias_pattern, policy)
