@@ -4,7 +4,7 @@ Advanced (ie. stronger) password hashers.
 This module relies on `passlib` to provide more secure hashers.
 """
 
-from passlib.hash import bcrypt, md5_crypt, sha256_crypt, sha512_crypt
+from passlib.hash import bcrypt, md5_crypt, sha256_crypt, sha512_crypt, ldap_salted_sha1
 
 try:
     from argon2 import PasswordHasher as argon2_hasher
@@ -40,7 +40,7 @@ class BLFCRYPTHasher(PasswordHasher):
         # rounds = parameters.get_global_parameter("rounds_number")
         # To get around this, I use the default of 12.
         rounds = 12
-        return bcrypt.hash(clearvalue, rounds=rounds)
+        return bcrypt.using(rounds=rounds).hash(clearvalue)
 
     def verify(self, clearvalue, hashed_value):
         return bcrypt.verify(clearvalue, hashed_value)
@@ -52,6 +52,7 @@ class MD5CRYPTHasher(PasswordHasher):
 
     This scheme can't be considered as secure anymore.
     """
+
     _weak = True
 
     @property
@@ -85,7 +86,7 @@ class SHA256CRYPTHasher(PasswordHasher):
 
     def _encrypt(self, clearvalue, salt=None):
         rounds = param_tools.get_global_parameter("rounds_number")
-        return sha256_crypt.hash(clearvalue, rounds=rounds)
+        return sha256_crypt.using(rounds=rounds).hash(clearvalue)
 
     def verify(self, clearvalue, hashed_value):
         return sha256_crypt.verify(clearvalue, hashed_value)
@@ -107,13 +108,34 @@ class SHA512CRYPTHasher(PasswordHasher):
 
     def _encrypt(self, clearvalue, salt=None):
         rounds = param_tools.get_global_parameter("rounds_number")
-        return sha512_crypt.hash(clearvalue, rounds=rounds)
+        return sha512_crypt.using(rounds=rounds).hash(clearvalue)
 
     def verify(self, clearvalue, hashed_value):
         return sha512_crypt.verify(clearvalue, hashed_value)
 
 
+class SSHAHasher(PasswordHasher):
+    """
+    Salted SHA1 password hasher.
+    """
+
+    _weak = True
+
+    @property
+    def scheme(self):
+        return "{SSHA}"
+
+    def _encrypt(self, clearvalue, salt=None):
+        # We have to remove the {SSHA} at the beginning of the string
+        return ldap_salted_sha1.hash(clearvalue)[6:]
+
+    def verify(self, clearvalue, hashed_value):
+        # We have to add the scheme for the hashed_value to be validated
+        return ldap_salted_sha1.verify(clearvalue, f"{{SSHA}}{hashed_value}")
+
+
 if argon2_hasher is not None:
+
     class ARGON2IDHasher(PasswordHasher):
         """
         argon2 password hasher.
@@ -123,8 +145,10 @@ if argon2_hasher is not None:
         but can only be used with dovecot >= 2.3 and libsodium >= 1.0.13
         """
 
-        def __init__(self,):
-            super(ARGON2IDHasher, self).__init__()
+        def __init__(
+            self,
+        ):
+            super().__init__()
 
             parameters = dict()
 
@@ -156,9 +180,9 @@ if argon2_hasher is not None:
                 return False
 
         def needs_rehash(self, hashed_value):
-            return self.hasher.check_needs_rehash(
-                hashed_value.strip(self.scheme)
-            )
+            return self.hasher.check_needs_rehash(hashed_value.strip(self.scheme))
+
 else:
+
     class ARGON2IDHasher:
         pass
