@@ -16,6 +16,7 @@ from django.urls import reverse
 from django.utils import timezone
 
 from modoboa.lib.tests import ModoTestCase, SimpleModoTestCase
+from modoboa.maillog import factories as maillog_factories, models as maillog_models
 from .. import factories, mocks, models
 
 
@@ -60,12 +61,16 @@ class ManagementCommandsTestCase(SimpleModoTestCase):
 
     def test_clean_logs(self):
         """Run cleanlogs command."""
+        management.call_command("load_initial_data", "--no-frontend")
         log1 = factories.LogFactory()
         factories.LogFactory()
         log1.date_created -= relativedelta(years=2)
         log1.save(update_fields=["date_created"])
+        maillog_factories.MaillogFactory(date=timezone.now() - relativedelta(days=190))
+        maillog_factories.MaillogFactory()
         management.call_command("cleanlogs")
         self.assertEqual(models.Log.objects.count(), 1)
+        self.assertEqual(maillog_models.Maillog.objects.count(), 1)
 
     def test_init_data_non_duplicate_client_creation(self):
         """Test that the load_initial_data command does not create duplicates
@@ -86,20 +91,61 @@ class ManagementCommandsTestCase(SimpleModoTestCase):
             self.addCleanup(shutil.rmtree, frontend_src)
 
         frontend_dir = pathlib.Path(settings.BASE_DIR) / "frontend"
-        self.assertFalse(frontend_dir.exists(), f"frontend directory {frontend_dir} doesn’t exist before load_initial_data")
+        self.assertFalse(
+            frontend_dir.exists(),
+            f"frontend directory {frontend_dir} doesn’t exist before load_initial_data",
+        )
         management.call_command("load_initial_data")
-        self.assertTrue(frontend_dir.is_dir(), f"frontend directory {frontend_dir} is directory after load_initial_data")
+        self.assertTrue(
+            frontend_dir.is_dir(),
+            f"frontend directory {frontend_dir} is directory after load_initial_data",
+        )
         for entry in frontend_dir.iterdir():
             if entry.name == "config.json":
-                self.assertTrue(entry.is_file() and not entry.is_symlink(), f"frontend directory entry {entry} is regular file")
+                self.assertTrue(
+                    entry.is_file() and not entry.is_symlink(),
+                    f"frontend directory entry {entry} is regular file",
+                )
                 try:
                     content = json.loads(entry.read_text("utf-8"))
                 except (ValueError, UnicodeDecodeError):
-                    self.fail(f"frontend directory entry {entry} is not UTF-8 encoded JSON")
-                for key_name in ("API_BASE_URL", "OAUTH_AUTHORITY_URL", "OAUTH_CLIENT_ID", "OAUTH_REDIRECT_URI", "OAUTH_POST_REDIRECT_URI"):
+                    self.fail(
+                        f"frontend directory entry {entry} is not UTF-8 encoded JSON"
+                    )
+                for key_name in (
+                    "API_BASE_URL",
+                    "OAUTH_AUTHORITY_URL",
+                    "OAUTH_CLIENT_ID",
+                    "OAUTH_REDIRECT_URI",
+                    "OAUTH_POST_REDIRECT_URI",
+                ):
                     self.assertIn(key_name, content)
             else:
-                self.assertTrue(entry.is_symlink(), f"frontend directory entry {entry} is symlink")
+                self.assertTrue(
+                    entry.is_symlink(), f"frontend directory entry {entry} is symlink"
+                )
+
+    def test_init_data_relative_urls(self):
+        """Test behavior of --relative-urls-in-config option."""
+        # Create our own dummy frontend directory if `vite` hasn’t been invoked yet
+        frontend_src = pathlib.Path(__file__).parent.parent.parent / "frontend_dist"
+        if not frontend_src.is_dir():
+            (frontend_src / "dummy").mkdir(parents=True)
+            self.addCleanup(shutil.rmtree, frontend_src)
+
+        management.call_command("load_initial_data", "--relative-urls-in-config")
+        frontend_dir = pathlib.Path(settings.BASE_DIR) / "frontend"
+        filepath = f"{frontend_dir}/config.json"
+        self.assertTrue(frontend_dir.exists())
+        with open(filepath) as fp:
+            config = json.loads(fp.read())
+        for param in [
+            "API_BASE_URL",
+            "API_DOC_URL",
+            "OAUTH_REDIRECT_URI",
+            "OAUTH_POST_REDIRECT_URI",
+        ]:
+            self.assertFalse(config[param].startswith("http"))
 
     def test_clean_inactive_accounts(self):
         """Run clean_inactive_accounts command."""
@@ -140,6 +186,30 @@ class ManagementCommandsTestCase(SimpleModoTestCase):
         with self.assertRaises(models.User.DoesNotExist):
             account.refresh_from_db()
 
+    def test_add_allowed_hosts(self):
+        with self.assertRaises(management.CommandError):
+            management.call_command(
+                "add_allowed_hosts", "app1.domain.tld", "app2.domain.tld"
+            )
+        management.call_command("load_initial_data")
+        management.call_command(
+            "add_allowed_hosts", "app1.domain.tld", "app2.domain.tld"
+        )
+        app_model = get_application_model()
+        app = app_model.objects.filter(name="modoboa_frontend").first()
+        self.assertIn("app1.domain.tld", app.redirect_uris)
+        self.assertIn("app2.domain.tld", app.redirect_uris)
+        self.assertIn("app1.domain.tld", app.post_logout_redirect_uris)
+        self.assertIn("app2.domain.tld", app.post_logout_redirect_uris)
+
+        # Check if same hostname is not added more than once
+        uri_count = len(app.redirect_uris.split(" "))
+        management.call_command(
+            "add_allowed_hosts", "app1.domain.tld", "app2.domain.tld"
+        )
+        app.refresh_from_db()
+        self.assertEqual(len(app.redirect_uris.split(" ")), uri_count)
+
 
 class APICommunicationTestCase(ModoTestCase):
     """Check communication with the API."""
