@@ -4,7 +4,7 @@ import datetime
 
 from django.db import models
 from django.utils import timezone
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from . import constants
 from . import lib
@@ -19,8 +19,11 @@ class DNSRecordManager(models.Manager):
         DNS queries are not performed while `ttl` (in seconds) is still valid.
         """
         now = timezone.now()
-        record = self.get_queryset().filter(
-            domain=domain, type=rtype, updated__gt=now).first()
+        record = (
+            self.get_queryset()
+            .filter(domain=domain, type=rtype, updated__gt=now)
+            .first()
+        )
         if record:
             return record
 
@@ -38,8 +41,7 @@ class DNSRecord(models.Model):
     """A model to store DNS records for Domain."""
 
     domain = models.ForeignKey("admin.Domain", on_delete=models.CASCADE)
-    type = models.CharField(
-        max_length=15, choices=constants.DNS_RECORD_TYPES)
+    type = models.CharField(max_length=15, choices=constants.DNS_RECORD_TYPES)
     value = models.TextField(blank=True)
     is_valid = models.BooleanField(default=False)
     error = models.CharField(max_length=50, null=True, blank=True)
@@ -48,24 +50,25 @@ class DNSRecord(models.Model):
     objects = DNSRecordManager()
 
     def __str__(self):
-        return "{} ({}): {}".format(self.domain, self.type, self.value)
+        return f"{self.domain} ({self.type}): {self.value}"
 
     def get_dns_record(self):
         """Retrieve corresponding DNS record."""
         if self.type == "dkim":
             self.value = lib.get_dkim_record(
-                self.domain.name, self.domain.dkim_key_selector)
+                self.domain.name, self.domain.dkim_key_selector
+            )
         else:
-            func = getattr(lib, "get_{}_record".format(self.type))
+            func = getattr(lib, f"get_{self.type}_record")
             self.value = func(self.domain.name)
 
     def check_syntax(self, ttl=7200):
         """Check record syntax."""
         try:
-            func = getattr(lib, "check_{}_syntax".format(self.type))
+            func = getattr(lib, f"check_{self.type}_syntax")
             result = func(self.value)
         except lib.DNSSyntaxError as err:
-            self.error = str(err)
+            self.error = str(err)[:50]
             self.updated = timezone.now()
             return
         except AttributeError:
