@@ -2,6 +2,7 @@
 
 from unittest import skipIf
 
+from django.conf import settings
 from django.core.management import call_command
 from django.utils.encoding import force_bytes, force_str
 
@@ -21,19 +22,22 @@ class LDAPExportTestCase(ModoTestCase):
 
     def setUp(self):
         super().setUp()
-        self.set_global_parameters({
-            "ldap_enable_sync": True,
-            "ldap_server_port": 3389,
-            "ldap_sync_bind_dn": "cn=admin,dc=example,dc=com",
-            "ldap_sync_bind_password": "test",
-            "ldap_sync_account_dn_template": (
-                "cn=%(user)s,ou=users,dc=example,dc=com"),
-        }, app="core")
+        self.set_global_parameters(
+            {
+                "ldap_enable_sync": True,
+                "ldap_server_port": settings.LDAP_SERVER_PORT,
+                "ldap_sync_bind_dn": "cn=admin,dc=example,dc=com",
+                "ldap_sync_bind_password": "test",
+                "ldap_sync_account_dn_template": (
+                    "cn=%(user)s,ou=users,dc=example,dc=com"
+                ),
+            },
+            app="core",
+        )
         self.config = dict(param_tools.get_global_parameters("core"))
         self.conn = lib.get_connection(self.config)
         self.username = "testldap@test.com"
-        self.dn = self.config["ldap_sync_account_dn_template"] % {
-            "user": self.username}
+        self.dn = self.config["ldap_sync_account_dn_template"] % {"user": self.username}
 
     def reset_ldap_directory(self):
         try:
@@ -47,7 +51,7 @@ class LDAPExportTestCase(ModoTestCase):
             username=self.username,
             first_name="Test",
             last_name="LDAP",
-            groups=("SimpleUsers",)
+            groups=("SimpleUsers",),
         )
         self.assertTrue(lib.check_if_dn_exists(self.conn, self.dn))
 
@@ -58,8 +62,9 @@ class LDAPExportTestCase(ModoTestCase):
         lib.get_connection(self.config, self.dn, "toto")
 
         res = self.conn.search_s(
-            force_str(self.dn), ldap.SCOPE_SUBTREE,
-            force_str("(&(objectClass=inetOrgPerson))")
+            force_str(self.dn),
+            ldap.SCOPE_SUBTREE,
+            force_str("(&(objectClass=inetOrgPerson))"),
         )
         self.assertIn(force_bytes(user.last_name), res[0][1]["sn"])
 
@@ -69,7 +74,7 @@ class LDAPExportTestCase(ModoTestCase):
             username=self.username,
             first_name="Test",
             last_name="LDAP",
-            groups=("DomainAdmins", )
+            groups=("DomainAdmins",),
         )
         self.assertFalse(lib.check_if_dn_exists(self.conn, self.dn))
 
@@ -79,12 +84,13 @@ class LDAPExportTestCase(ModoTestCase):
             username=self.username,
             first_name="Test",
             last_name="LDAP",
-            groups=("SimpleUsers",)
+            groups=("SimpleUsers",),
         )
         user.delete()
         ldap_record = self.conn.search_s(
-            force_str(self.dn), ldap.SCOPE_SUBTREE,
-            force_str("(&(objectClass=inetOrgPerson))")
+            force_str(self.dn),
+            ldap.SCOPE_SUBTREE,
+            force_str("(&(objectClass=inetOrgPerson))"),
         )
         password = ldap_record[0][1]["userPassword"][0].split(b"}")[1]
         self.assertTrue(password.startswith(b"#"))
@@ -95,10 +101,9 @@ class LDAPExportTestCase(ModoTestCase):
             username=self.username,
             first_name="Test",
             last_name="LDAP",
-            groups=("SimpleUsers",)
+            groups=("SimpleUsers",),
         )
-        self.set_global_parameter(
-            "ldap_sync_delete_remote_account", True, app="core")
+        self.set_global_parameter("ldap_sync_delete_remote_account", True, app="core")
         user.delete()
         self.assertFalse(lib.check_if_dn_exists(self.conn, self.dn))
 
@@ -109,23 +114,27 @@ class LDAPImportTestCase(ModoTestCase):
 
     def setUp(self):
         super().setUp()
-        self.set_global_parameters({
-            "ldap_enable_import": True,
-            "ldap_server_port": 3389,
-            "ldap_sync_bind_dn": "cn=admin,dc=example,dc=com",
-            "ldap_sync_bind_password": "test",
-            "ldap_import_search_base": "ou=users,dc=example,dc=com",
-            "ldap_import_search_filter": "(objectClass=person)",
-            "ldap_groups_search_base": "ou=groups,dc=example,dc=com",
-            "ldap_admin_groups": "admins",
-        }, app="core")
+        self.set_global_parameters(
+            {
+                "ldap_enable_import": True,
+                "ldap_server_port": settings.LDAP_SERVER_PORT,
+                "ldap_sync_bind_dn": "cn=admin,dc=example,dc=com",
+                "ldap_sync_bind_password": "test",
+                "ldap_import_search_base": "ou=users,dc=example,dc=com",
+                "ldap_import_search_filter": "(objectClass=person)",
+                "ldap_groups_search_base": "ou=groups,dc=example,dc=com",
+                "ldap_admin_groups": "admins",
+            },
+            app="core",
+        )
         self.config = dict(param_tools.get_global_parameters("core"))
         self.conn = lib.get_connection(self.config)
 
     def test_import_from_ldap(self):
         """Check management command."""
         call_command("import_from_ldap_directory")
-        self.assertTrue(core_models.User.objects.filter(
-            username="testuser@example.com").exists())
+        self.assertTrue(
+            core_models.User.objects.filter(username="testuser@example.com").exists()
+        )
         admin = core_models.User.objects.get(username="mailadmin@example.com")
         self.assertEqual(admin.role, "DomainAdmins")
