@@ -1,5 +1,6 @@
 """External API urls."""
 
+from django.conf import settings
 from django.urls import include, path
 
 from modoboa.core.extensions import exts_pool
@@ -25,4 +26,9 @@ urlpatterns = [
     path("webmail/", include("modoboa.webmail.urls")),
 ]
 
+if "modoboa.amavis" in settings.MODOBOA_APPS:
+    urlpatterns += [
+        path("amavis/", include("modoboa.amavis.urls")),
+    ]
+
 urlpatterns += exts_pool.get_urls(category="api")
