@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 
-from __future__ import unicode_literals
 
 import os
 import sys
@@ -20,6 +19,6 @@ if __name__ == "__main__":
                 "Couldn't import Django. Are you sure it's installed and "
                 "available on your PYTHONPATH environment variable? Did you "
                 "forget to activate a virtual environment?"
-            )
+            ) from None
         raise
     execute_from_command_line(sys.argv)
